pitchtools.NamedInterval
========================

.. abjad-lineage:: abjad.tools.pitchtools.NamedInterval.NamedInterval

.. autoclass:: abjad.tools.pitchtools.NamedInterval.NamedInterval

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.pitchtools.NamedInterval.NamedInterval.cents
      ~abjad.tools.pitchtools.NamedInterval.NamedInterval.direction_number
      ~abjad.tools.pitchtools.NamedInterval.NamedInterval.direction_string
      ~abjad.tools.pitchtools.NamedInterval.NamedInterval.from_pitch_carriers
      ~abjad.tools.pitchtools.NamedInterval.NamedInterval.interval_class
      ~abjad.tools.pitchtools.NamedInterval.NamedInterval.interval_string
      ~abjad.tools.pitchtools.NamedInterval.NamedInterval.is_named_interval_abbreviation
      ~abjad.tools.pitchtools.NamedInterval.NamedInterval.is_named_interval_quality_abbreviation
      ~abjad.tools.pitchtools.NamedInterval.NamedInterval.named_interval_class
      ~abjad.tools.pitchtools.NamedInterval.NamedInterval.number
      ~abjad.tools.pitchtools.NamedInterval.NamedInterval.quality_string
      ~abjad.tools.pitchtools.NamedInterval.NamedInterval.semitones
      ~abjad.tools.pitchtools.NamedInterval.NamedInterval.staff_spaces
      ~abjad.tools.pitchtools.NamedInterval.NamedInterval.__abs__
      ~abjad.tools.pitchtools.NamedInterval.NamedInterval.__add__
      ~abjad.tools.pitchtools.NamedInterval.NamedInterval.__copy__
      ~abjad.tools.pitchtools.NamedInterval.NamedInterval.__eq__
      ~abjad.tools.pitchtools.NamedInterval.NamedInterval.__float__
      ~abjad.tools.pitchtools.NamedInterval.NamedInterval.__format__
      ~abjad.tools.pitchtools.NamedInterval.NamedInterval.__ge__
      ~abjad.tools.pitchtools.NamedInterval.NamedInterval.__gt__
      ~abjad.tools.pitchtools.NamedInterval.NamedInterval.__hash__
      ~abjad.tools.pitchtools.NamedInterval.NamedInterval.__int__
      ~abjad.tools.pitchtools.NamedInterval.NamedInterval.__le__
      ~abjad.tools.pitchtools.NamedInterval.NamedInterval.__lt__
      ~abjad.tools.pitchtools.NamedInterval.NamedInterval.__mul__
      ~abjad.tools.pitchtools.NamedInterval.NamedInterval.__ne__
      ~abjad.tools.pitchtools.NamedInterval.NamedInterval.__neg__
      ~abjad.tools.pitchtools.NamedInterval.NamedInterval.__repr__
      ~abjad.tools.pitchtools.NamedInterval.NamedInterval.__rmul__
      ~abjad.tools.pitchtools.NamedInterval.NamedInterval.__str__
      ~abjad.tools.pitchtools.NamedInterval.NamedInterval.__sub__

Bases
-----

- :py:class:`pitchtools.Interval <abjad.tools.pitchtools.Interval.Interval>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.NamedInterval.NamedInterval.cents
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NamedInterval.NamedInterval.direction_number
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NamedInterval.NamedInterval.direction_string
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NamedInterval.NamedInterval.interval_class
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NamedInterval.NamedInterval.interval_string
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NamedInterval.NamedInterval.named_interval_class
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NamedInterval.NamedInterval.number
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NamedInterval.NamedInterval.quality_string
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NamedInterval.NamedInterval.semitones
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.NamedInterval.NamedInterval.staff_spaces
   :noindex:

Class methods
-------------

.. automethod:: abjad.tools.pitchtools.NamedInterval.NamedInterval.from_pitch_carriers
   :noindex:

Static methods
--------------

.. automethod:: abjad.tools.pitchtools.NamedInterval.NamedInterval.is_named_interval_abbreviation
   :noindex:

.. automethod:: abjad.tools.pitchtools.NamedInterval.NamedInterval.is_named_interval_quality_abbreviation
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.pitchtools.NamedInterval.NamedInterval.__abs__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NamedInterval.NamedInterval.__add__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NamedInterval.NamedInterval.__copy__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NamedInterval.NamedInterval.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NamedInterval.NamedInterval.__float__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NamedInterval.NamedInterval.__format__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NamedInterval.NamedInterval.__ge__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NamedInterval.NamedInterval.__gt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NamedInterval.NamedInterval.__hash__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NamedInterval.NamedInterval.__int__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NamedInterval.NamedInterval.__le__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NamedInterval.NamedInterval.__lt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NamedInterval.NamedInterval.__mul__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NamedInterval.NamedInterval.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NamedInterval.NamedInterval.__neg__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NamedInterval.NamedInterval.__repr__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NamedInterval.NamedInterval.__rmul__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NamedInterval.NamedInterval.__str__
   :noindex:

.. automethod:: abjad.tools.pitchtools.NamedInterval.NamedInterval.__sub__
   :noindex:
